diff --git a/utils/solvers/c++/solver.cpp b/utils/solvers/c++/solver.cpp
index b1abd41deade5680693a3172b91a07b6f2280c70..e58952d647e821f7a519553c01c854b1f4caf265 100644
--- a/utils/solvers/c++/solver.cpp
+++ b/utils/solvers/c++/solver.cpp
@@ -1,4 +1,4 @@
-// $Id: solver.cpp,v 1.8 2006-02-24 22:07:08 geuzaine Exp $
+// $Id: solver.cpp,v 1.9 2006-02-25 14:36:53 geuzaine Exp $
 //
 // Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
 //
@@ -100,9 +100,9 @@ int main(int argc, char *argv[])
     // do the computation and merge some views
     for(int i = 0; i < 10; i++){
       client.Info("Computing curve...");
-      // fake computation...
+      // fake computation for 500ms:
 #if !defined(WIN32) || defined(__CYGWIN__)
-      usleep(500);
+      usleep(500 * 1000);
 #else
       Sleep(500);
 #endif
diff --git a/utils/solvers/c/solver.c b/utils/solvers/c/solver.c
index 2846d45fa1310c85ef6543776af12260b50fc97b..dfa6a5aa7ae7a7ff00a79cad25854e544912463a 100644
--- a/utils/solvers/c/solver.c
+++ b/utils/solvers/c/solver.c
@@ -1,4 +1,4 @@
-/* $Id: solver.c,v 1.4 2006-02-25 00:15:01 geuzaine Exp $ */
+/* $Id: solver.c,v 1.5 2006-02-25 14:36:53 geuzaine Exp $ */
 /*
  * Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
  *
@@ -141,11 +141,11 @@ int main(int argc, char *argv[])
       for(i = 0; i < 10; i++) {
         sprintf(tmp, "%d %% complete", 10*i);
         Gmsh_SendString(s, GMSH_CLIENT_PROGRESS, tmp);
 	/* Fake some cpu-intensive calculation: */
 #if !defined(WIN32) || defined(__CYGWIN__)
-	usleep(500 * 1000);
+	usleep(100 * 1000);
 #else
-	Sleep(500);
+	Sleep(100);
 #endif
       }
       sprintf(tmp, "Done with %s!", name);
@@ -141,11 +141,11 @@ int main(int argc, char *argv[])
         sprintf(tmp, "%d %% complete", 10*i);
         Gmsh_SendString(s, GMSH_CLIENT_PROGRESS, tmp);
-	/* Fake some cpu-intensive calculation: */
+	/* Fake some cpu-intensive calculation during 100ms: */
 #if !defined(WIN32) || defined(__CYGWIN__)